
[Class ClientWithProject](https://cloud.google.com/python/docs/reference/google-cloud-core/latest/google.cloud.client.ClientWithProject)

# Dependency graph

`google-cloud-core`
- `google-api-core`
  - `protobuf`
  - `googleapis-common-protos`
  - `proto-plus`